@@ -202,6 +202,13 @@ void setgrid(xcWidget w, float *dataptr)
    /* Might be nice in the future to make it accept any input. . .    */
 
    switch (xobjs.pagelist[areastruct.page]->coordstyle) {
+      case INTERNAL:
+	 if (sscanf(_STR2, "%f", &fval) == 0) {
+	    *dataptr = oldvalue;
+	    Wprintf("Illegal value");
+	 }
+	 else *dataptr = fval / iscale;
+	 break;
       case CM:
          oscale = xobjs.pagelist[areastruct.page]->outscale * CMSCALE;
 	 if (sscanf(_STR2, "%f", &fval) == 0) {
@@ -244,6 +251,9 @@ void measurestr(float value, char *buffer)
         (float)(xobjs.pagelist[areastruct.page]->drawingscale.x);
 
    switch (xobjs.pagelist[areastruct.page]->coordstyle) {
+      case INTERNAL:
+         sprintf(buffer, "%5.3f", value * iscale);
+	 break;
       case CM:
          oscale = xobjs.pagelist[areastruct.page]->outscale * CMSCALE;
          sprintf(buffer, "%5.3f cm", value * iscale * oscale / IN_CM_CONVERT);
@@ -1312,6 +1322,7 @@ void togglegrid(u_short type)
    if (type == CM) button = XtNameToWidget(bparent, "Centimeters");
    else if (type == FRAC_INCH) button = XtNameToWidget(bparent, "Fractional Inches");
    else if (type == DEC_INCH) button = XtNameToWidget(bparent, "Decimal Inches");
+   else if (type == INTERNAL) button = XtNameToWidget(bparent, "Internal Units");
    else button = XtNameToWidget(bparent, "Coordinates");
    toggleexcl(button, GridStyles, XtNumber(GridStyles));
    W1printf(" ");
@@ -1363,7 +1374,7 @@ void getgridtype(xcWidget button, pointertype value, caddr_t calldata)
    xobjs.pagelist[areastruct.page]->coordstyle = (short)value;
 
    switch(value) {
-      case FRAC_INCH: case DEC_INCH:
+      case FRAC_INCH: case DEC_INCH: case INTERNAL:
 	 if (oldtype == CM) {
             xobjs.pagelist[areastruct.page]->outscale *= scalefac;
 #ifndef TCL_WRAPPER
