@@ -716,9 +716,11 @@ int textcompx(stringpart *string, char *text, Boolean exact, objinstptr localins
    char *tptr = text;
    char *sptr;
    int rval, llen = strlen(text), slen;
+   Boolean has_text = FALSE; 
 
    for (strptr = string; strptr != NULL; strptr = nextstringpart(strptr, localinst)) {
       if (strptr->type == TEXT_STRING) {
+	 has_text = TRUE;
 	 sptr = strptr->data.string;
 	 slen = min(strlen(sptr), llen);
 	 llen -= slen;
@@ -732,7 +734,9 @@ int textcompx(stringpart *string, char *text, Boolean exact, objinstptr localins
 	    tptr += slen;
       }
    }
-   return 0;
+
+   /* Check condition that no text was encountered in the xcircuit string */
+   return ((llen > 0) && !has_text) ? 1 : 0;
 }
 
 /*----------------------------------------------------------------------*/
